@@ -29,11 +29,11 @@ import subprocess
 labels = { "t" : "Time, $t \, (ps)$", \
            "nu" : r"Frequency, $\nu \, (THz)$", \
            "Lambda" : r"Wavelength, $\lambda \, (nm)$", \
-           "P_t" : "Temporal power, $|A(z, t)|^2 \, (W)$", \
-           "P_nu" : r"Spectral power, $|A(z, \nu)|^2 \, (a.u.)$", \
-           "P_lambda" : r"Spectral power, $|A(z, \lambda|^2 \, (a.u.)$", \
+           "P_t" : "Power, $|A(z, t)|^2 \, (W)$", \
+           "P_nu" : r"Power, $|A(z, \nu)|^2 \, (a.u.)$", \
+           "P_lambda" : r"Power, $|A(z, \lambda|^2 \, (a.u.)$", \
            "z" : "Fibre length, $z \, (km)$", \
-           "phi" : "Temporal phase, $\phi(t) \, (rad)$", \
+           "phi" : "Phase, $\phi(t) \, (rad)$", \
            "chirp" : "Frequency chirp, $\delta \omega \, (rad / ps)$", \
            "t_normal" : r"Normalised time, $\frac{t}{T_0}$", \
            "xi" : r"Normalised distance, $\xi = \frac{z}{L_D}$", \
@@ -76,12 +76,15 @@ def map_plot( x, y, z, x_label = "", y_label = "", z_label = "",
                     extent = (x[0], x[-1], z[0], z[-1]) )
    # ===========================================================================
    # Draw a colour bar showing mapping of colours to values for y-axis:
-   cb = plt.colorbar()
+   cb = plt.colorbar( im, use_gridspec = True )
    cb.set_label( y_label )
    # ===========================================================================
    if( y_range is not None ):
       im.set_clim( y_range )
    # ===========================================================================
+   # Avoid overlapping axis text:
+   plt.tight_layout()
+   # ===========================================================================
    if( filename ):
       plt.savefig( filename, dpi = dpi )
       print "Wrote file", filename
@@ -143,6 +146,9 @@ def waterfall_plot( x, y, z, x_label = "", y_label = "", z_label = "",
    if( y_range is not None ):
       ax.set_zlim3d( y_range )
    # ===========================================================================
+   # Avoid overlapping axis text:
+   plt.tight_layout()
+   # ===========================================================================
    if( filename ):
       plt.savefig( filename, dpi = dpi )
       print "Wrote file", filename
@@ -249,6 +255,9 @@ def double_plot( x, y, X, Y, x_label = "", y_label = "", X_label = "",
    if( Y_range is not None ):
       ax2.set_ylim( Y_range )
    # ===========================================================================
+   # Avoid overlapping axis text:
+   plt.tight_layout()
+   # ===========================================================================
    if( filename ):
       plt.savefig( filename, dpi = dpi )
       print "Wrote file", filename
@@ -362,6 +371,9 @@ def quad_plot( x, ys, zs, x_label = "", y_label = "", z_labels = [""],
    ax3.set_xlabel( x_label )
    ax4.set_xlabel( x_label )
    # ===========================================================================
+   # Avoid overlapping axis text:
+   plt.tight_layout()
+   # ===========================================================================
    if( filename ):
       plt.savefig( filename, dpi = dpi )
       print "Wrote file", filename
